==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/GitLabIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GitLabIdentityProviderFluent<A extends GitLabIdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getCa();
  public ConfigMapNameReference buildCa();
  public A withCa(ConfigMapNameReference ca);
  public Boolean hasCa();
  public A withNewCa(String name);
  public GitLabIdentityProviderFluent.CaNested<A> withNewCa();
  public GitLabIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
  public GitLabIdentityProviderFluent.CaNested<A> editCa();
  public GitLabIdentityProviderFluent.CaNested<A> editOrNewCa();
  public GitLabIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
  public String getClientID();
  public A withClientID(String clientID);
  public Boolean hasClientID();
  
  /**
   * This method has been deprecated, please use method buildClientSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getClientSecret();
  public SecretNameReference buildClientSecret();
  public A withClientSecret(SecretNameReference clientSecret);
  public Boolean hasClientSecret();
  public A withNewClientSecret(String name);
  public GitLabIdentityProviderFluent.ClientSecretNested<A> withNewClientSecret();
  public GitLabIdentityProviderFluent.ClientSecretNested<A> withNewClientSecretLike(SecretNameReference item);
  public GitLabIdentityProviderFluent.ClientSecretNested<A> editClientSecret();
  public GitLabIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecret();
  public GitLabIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecretLike(SecretNameReference item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CaNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<GitLabIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface ClientSecretNested<N> extends Nested<N>,SecretNameReferenceFluent<GitLabIdentityProviderFluent.ClientSecretNested<N>>{
    public N and();
    public N endClientSecret();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/GitLabIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GitLabIdentityProviderFluent<A extends GitLabIdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getCa();
  public ConfigMapNameReference buildCa();
  public A withCa(ConfigMapNameReference ca);
  public Boolean hasCa();
  public A withNewCa(String name);
  public GitLabIdentityProviderFluent.CaNested<A> withNewCa();
  public GitLabIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
  public GitLabIdentityProviderFluent.CaNested<A> editCa();
  public GitLabIdentityProviderFluent.CaNested<A> editOrNewCa();
  public GitLabIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
  public String getClientID();
  public A withClientID(String clientID);
  public Boolean hasClientID();
  
  /**
   * This method has been deprecated, please use method buildClientSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getClientSecret();
  public SecretNameReference buildClientSecret();
  public A withClientSecret(SecretNameReference clientSecret);
  public Boolean hasClientSecret();
  public A withNewClientSecret(String name);
  public GitLabIdentityProviderFluent.ClientSecretNested<A> withNewClientSecret();
  public GitLabIdentityProviderFluent.ClientSecretNested<A> withNewClientSecretLike(SecretNameReference item);
  public GitLabIdentityProviderFluent.ClientSecretNested<A> editClientSecret();
  public GitLabIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecret();
  public GitLabIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecretLike(SecretNameReference item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CaNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<GitLabIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface ClientSecretNested<N> extends Nested<N>,SecretNameReferenceFluent<GitLabIdentityProviderFluent.ClientSecretNested<N>>{
    public N and();
    public N endClientSecret();
    
  }
  
}
